@extends('layouts.print')

@section('header')
<p class="header-text">
    @foreach (Session::get('semesters_info') as $index => $semester_info)
        {{ $semester_info }}
        @if($index+1 != count(Session::get('semesters_info')))
        <strong>&#183;</strong>
        @endif
    @endforeach
</p>
<p class="header-text">Assessment Report</p>
<h1 class="header-text">School of {{{ $school->name}}}</h1>
@stop

@section('main')

<div class="row">
    <div class="col-md-12" id="graph"></div>
</div>
<br>
<br>
<br>
<h3>Programs</h3>
<table class="tabletable-condensed">
    <tr>
        <th>Name</th>
        <th>Participation</th>
    </tr>
    @foreach ($school->programs as $program)
        <tr>
            <td>{{ $program->name }}</td>
            <td class="text-center">
                @if(in_array($program->id, $participating_programs))
                    <span class="glyphicon glyphicon-ok"></span>
                @else
                    -
                @endif
            </td>
        </tr>
    @endforeach
</table>

<h3>Assessment Results by Learning Outcomes in Academic Programs</h3>
<table>
    <thead>
        <th>Learning Outcome</th>
        <th>Programs Achieved</th>
        <th>Programs doing Assessment</th>
        <th>Success Rate</th>
    </thead>
    <tbody>
        @foreach($outcomes as $outcome)
            <tr>
                <td class="col-md-6">{{ $outcome->name }}</td>
                <td class="col-md-2">{{{ $achievedProgramsPerOutcome[$outcome->id] }}}</td>
                <td class="col-md-2">{{{ $attemptedProgramsPerOutcome[$outcome->id] }}}</td>
                <td class="col-md-2">
                    @if($attemptedProgramsPerOutcome[$outcome->id]!=0)
                        {{{ round($achievedProgramsPerOutcome[$outcome->id] / $attemptedProgramsPerOutcome[$outcome->id]*100, 2) }}}%
                    @else
                        N/M
                    @endif
                </td>
            </tr>
        @endforeach
    </tbody>
    <tfoot></tfoot>
    <caption>N/M: Not Measured</caption>
</table>

<h3>Courses</h3>
@if($school_sections_count>0)
    <table>
        <thead>
            <tr>
                <th>Identifier</th>
                <th>Name</th>
                <th>Program</th>
                <th>Assessed and Published</th>
            </tr>
        </thead>
        <tbody>
            @foreach($grouped_courses as $grouped_course)
                <tr>
                    <td class="col-md-2">{{ $grouped_course->code.$grouped_course->number.' ('.$grouped_course->semester->code.')' }}</td>
                    <td class="col-md-4">{{{ $grouped_course->name}}}</td>
                    <td class="col-md-2">{{{ $grouped_course->program->name }}}</td>
                    <td class="col-md-1">
                        @if($grouped_course->outcomes_attempted!=NULL)
                            Yes
                        @else
                            No
                        @endif
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
@else
    <p class="lead"> No courses assigned.</p>
@endif

<h3>Sections</h3>
@if($school_sections_count>0)
    <p class="lead"> {{{ $assessed_sections_count }}} out of {{{ $school_sections_count }}} section(s) doing Assessment ({{{ round($assessed_sections_count/$school_sections_count*100, 2) }}}%)</p>
    <table>
        <thead>
            <tr>
                <th>Identifier</th>
                <th>Name</th>
                <th>Program</th>
                <th>Professor</th>
                <th>Assessed Activities</th>
                <th>Assessed Results</th>
            </tr>
        </thead>
        <tbody>
            @foreach($school->programs as $program)
                @foreach($program->courses as $course)
                <tr>
                    <td class="col-md-2">{{ $course->code.$course->number.'-'.$course->section.' ('.$course->semester->code.')' }}</td>
                    <td class="col-md-4">{{{ $course->name}}}</td>
                    <td class="col-md-2">{{{ $course->program->name }}}</td>
                    <td class="col-md-3">{{{ $course->user->surnames }}}, {{{ $course->user->first_name }}}</td>
                    <td class="col-md-1">
                        @if(count($course->assessedActivities))
                            <span class="glyphicon glyphicon-ok"></span>
                        @endif
                    </td>
                    <td class="col-md-1">
                        @if(count($course->publishedActivities))
                            <span class="glyphicon glyphicon-ok"></span>
                        @endif
                    </td>
                </tr>
                @endforeach
            @endforeach
        </tbody>
    </table>
@else
    <p class="lead"> No sections assigned.</p>
@endif

@stop

@section('included-js')

<!-- HighCharts -->
<script src="{{ asset('vendor/highcharts/highcharts.js') }}"></script>
<!--script src="http://code.highcharts.com/modules/exporting.js"></script -->

@stop

@section('javascript')
$(function () {

    $('#schoolTabs a').click(function (e) {
        e.preventDefault()
        $(this).tab('show');
    });

    $('#graph').highcharts({
        chart: {
            type: 'bar'
        },
        title: {
            text: 'Performance by Learning Outcome Criteria in {{ $school->name }}'
        },
        legend: {
            reversed: true,
        },
        xAxis: {
            categories: [
                @foreach($outcomes as $outcome)
                    "{{{ $outcome->name }}}",
                @endforeach
            ],
            labels: {
                style: {
                    fontSize:'11px'
                },
                step:1,
                useHTML:true,
                formatter: function() {
                    return '<div style="width:200px; word-break:break; text-overflow:ellipsis; overflow:hidden;">'+this.value+'</div>';
                },
            }
        },
        yAxis: {
            min: 0,
            max: 100,
            title: {
                text: 'Percentage'
            }
        },
        tooltip: {
            enabled: false,
        },
        plotOptions: {
            bar: {
                //grouping: false,
                shadow: false,
                borderWidth: 0,
            },
            series: {
            pointPadding: 0,
            groupPadding: 0.075
            },
        },
        series: [{
            name: 'Expected Value',
            color: '#555555',
            dataLabels: {
                enabled: true,
                fontSize: 8,
                color: '#fff',
                align: 'right',
                format: '{y:.1f}%',
                style: {
                    //fontWeight: 'bold'
                },
                y:-1
            },
            data: [
                @foreach($outcomes as $index => $outcome)
                    @if(
                        is_array($outcomes_attempted)
                        && array_key_exists($outcome->id, $outcomes_attempted)
                        && $outcomes_attempted[$outcome->id]!=0)
                        {{{ $outcome->expected_outcome }}},
                    @else
                        0,
                    @endif
                @endforeach
            ]

        }, {
            name: 'Obtained Value',
            color: '#e70033',
            dataLabels: {
                enabled: true,
                fontSize: 8,
                color: '#fff',
                align: 'right',
                format: '{y:.1f}%',
                style: {
                    //fontWeight: 'bold'
                },
                y:-1
            },
            data:[
                @foreach($outcomes as $index => $outcome)
                    @if(
                        is_array($outcomes_attempted)
                        && array_key_exists($outcome->id, $outcomes_attempted)
                        && $outcomes_attempted[$outcome->id]!=0)
                        {{{ ($outcomes_achieved[$outcome->id]/$outcomes_attempted[$outcome->id])*100 }}},
                    @else
                        0,
                    @endif
                @endforeach

            ]
        }, ]
    });

    // Include dummy graph for outcomes
    @include('global.dummy-outcomes')
});

@stop
